*************
API Reference
*************

Auto-generated reference from source docstrings.

.. contents:: Modules
   :local:
   :depth: 2

Module: ``arr`` — Array Utilities
=================================

.. automodule:: ut_arr.arr
   :members:
   :undoc-members:
   :show-inheritance:

Module: ``ao2a`` — Array of Two Arrays
=======================================

.. automodule:: ut_arr.ao2a
   :members:
   :undoc-members:
   :show-inheritance:

Module: ``aoa`` — Array of Arrays
==================================

.. automodule:: ut_arr.aoa
   :members:
   :undoc-members:
   :show-inheritance:

Module: ``aod`` — Array of Dictionaries
========================================

.. automodule:: ut_arr.aod
   :members:
   :undoc-members:
   :show-inheritance:

Module: ``aoo`` — Array of Objects
===================================

.. automodule:: ut_arr.aoo
   :members:
   :undoc-members:
   :show-inheritance:

Module: ``aos`` — Array of Strings
===================================

.. automodule:: ut_arr.aos
   :members:
   :undoc-members:
   :show-inheritance:
